@@ -5,7 +5,10 @@ import builtins
 import keyword
 import textwrap
 import typing
-from typing import List
+from typing import Dict, List
+from unittest.mock import MagicMock
+
+from botocore.utils import get_service_module_name
 
 RESERVED_NAMES = set(
     (
@@ -139,3 +142,28 @@ def get_short_docstring(doc: str) -> str:
         result_str = f"{result_str}."
 
     return "\n".join(textwrap.wrap(result_str, width=80))
+
+
+def get_botocore_class_name(metadata: Dict[str, str]) -> str:
+    """
+    Get Botocore class name from Service metadata.
+    """
+    service_model = MagicMock()
+    service_model.service_name = metadata.get("serviceId", "")
+    service_model.metadata = metadata
+    return get_service_module_name(service_model)
+
+
+def get_min_build_version(version: str) -> str:
+    """
+    Get min version 5 micro releases lower that `version`.
+
+    Minimum micro is 0.
+    """
+    major = minor = micro = "0"
+    if version.count(".") > 2:
+        major, minor, micro, _ = version.split(".", 3)
+    else:
+        major, minor, micro = version.split(".", 2)
+    new_micro = max(int(micro) - 5, 0)
+    return f"{major}.{minor}.{new_micro}"
