@@ -1,13 +1,13 @@
 """
 botocore-stubs package writer.
 """
-import filecmp
-import shutil
 from pathlib import Path
 from typing import List, Tuple
 
 from mypy_boto3_builder.constants import BOTOCORE_STUBS_NAME, BOTOCORE_STUBS_STATIC_PATH
+from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.utils.markdown import fix_pypi_headers
+from mypy_boto3_builder.utils.nice_path import NicePath
 from mypy_boto3_builder.writers.utils import (
     blackify,
     format_md,
@@ -17,7 +17,7 @@ from mypy_boto3_builder.writers.utils import (
 )
 
 
-def write_botocore_stubs_package(output_path: Path, generate_setup: bool) -> List[Path]:
+def write_botocore_stubs_package(output_path: Path, generate_setup: bool) -> None:
     """
     Generate botocore-stubs stub files.
 
@@ -25,20 +25,14 @@ def write_botocore_stubs_package(output_path: Path, generate_setup: bool) -> Lis
         output_path -- Path to output folder.
         generate_setup -- Generate ready-to-install or to-use package.
     """
+    logger = get_logger()
     setup_path = output_path / "botocore_stubs_package"
-    if not generate_setup:
-        setup_path = output_path
+    if generate_setup:
+        package_path = setup_path / BOTOCORE_STUBS_NAME
+    else:
+        package_path = output_path / "botocore"
 
-    modified_paths: List[Path] = []
-    package_path = setup_path / BOTOCORE_STUBS_NAME
-    if not generate_setup:
-        package_path = setup_path / "botocore"
-
-    if setup_path.exists():
-        shutil.rmtree(setup_path)
-
-    setup_path.mkdir(exist_ok=True)
-    package_path.mkdir(exist_ok=True)
+    package_path.mkdir(exist_ok=True, parents=True)
 
     templates_path = Path("botocore-stubs")
     module_templates_path = templates_path / "botocore-stubs"
@@ -73,17 +67,21 @@ def write_botocore_stubs_package(output_path: Path, generate_setup: bool) -> Lis
             content = fix_pypi_headers(content)
             content = format_md(content)
         if not file_path.exists() or file_path.read_text() != content:
-            modified_paths.append(file_path)
             file_path.write_text(content)
+            logger.debug(f"Updated {NicePath(file_path)}")
 
+    static_paths = []
     for static_path in BOTOCORE_STUBS_STATIC_PATH.glob("**/*.pyi"):
         relative_output_path = static_path.relative_to(BOTOCORE_STUBS_STATIC_PATH)
         file_path = package_path / relative_output_path
+        static_paths.append(file_path)
         file_path.parent.mkdir(exist_ok=True)
-        if file_path.exists() and filecmp.cmp(static_path.as_posix(), file_path.as_posix()):
-            continue
+        content = static_path.read_text()
+        if not file_path.exists() or file_path.read_text() != content:
+            file_path.write_text(content)
+            logger.debug(f"Updated {NicePath(file_path)}")
 
-        shutil.copy(static_path, file_path)
-        modified_paths.append(file_path)
-
-    return modified_paths
+    valid_paths = (*dict(file_paths).keys(), *static_paths)
+    for unknown_path in NicePath(setup_path if generate_setup else package_path).walk(valid_paths):
+        unknown_path.unlink()
+        logger.debug(f"Deleted {NicePath(unknown_path)}")
