@@ -2,7 +2,7 @@
 Processors for parsing and writing modules.
 """
 from pathlib import Path
-from typing import List
+from typing import Iterable
 
 from boto3.session import Session
 
@@ -14,6 +14,7 @@ from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.boto3_stubs_package import Boto3StubsPackage
 from mypy_boto3_builder.structures.master_package import MasterPackage
 from mypy_boto3_builder.structures.service_package import ServicePackage
+from mypy_boto3_builder.type_annotations.type_literal import TypeLiteral
 from mypy_boto3_builder.utils.nice_path import NicePath
 from mypy_boto3_builder.writers.boto3_stubs_package import (
     write_boto3_stubs_docs,
@@ -27,7 +28,7 @@ from mypy_boto3_builder.writers.service_package import write_service_docs, write
 def process_boto3_stubs(
     session: Session,
     output_path: Path,
-    service_names: List[ServiceName],
+    service_names: Iterable[ServiceName],
     generate_setup: bool,
 ) -> Boto3StubsPackage:
     """
@@ -71,7 +72,7 @@ def process_botocore_stubs(
 def process_master(
     session: Session,
     output_path: Path,
-    service_names: List[ServiceName],
+    service_names: Iterable[ServiceName],
     generate_setup: bool,
 ) -> MasterPackage:
     """
@@ -100,15 +101,17 @@ def process_service(
     service_name: ServiceName,
     output_path: Path,
     generate_setup: bool,
+    service_names: Iterable[ServiceName],
 ) -> ServicePackage:
     """
     Parse and write service package `mypy_boto3_*`.
 
     Arguments:
-        session -- boto3 session.
-        service_name -- Target service name.
-        output_path -- Package output path.
-        generate_setup -- Generate ready-to-install or to-use package.
+        session -- boto3 session
+        service_name -- Target service name
+        output_path -- Package output path
+        generate_setup -- Generate ready-to-install or to-use package
+        service_names -- List of known service names
 
     Return:
         Parsed ServicePackage.
@@ -116,6 +119,9 @@ def process_service(
     logger = get_logger()
     logger.debug(f"Parsing {service_name.boto3_name}")
     service_module = parse_service_package(session, service_name)
+    service_module.literals.append(
+        TypeLiteral("ServiceName", [i.boto3_name for i in service_names])
+    )
     for typed_dict in service_module.typed_dicts:
         typed_dict.replace_self_references()
     logger.debug(f"Writing {service_name.boto3_name} to {NicePath(output_path)}")
@@ -128,14 +134,16 @@ def process_service_docs(
     session: Session,
     service_name: ServiceName,
     output_path: Path,
+    service_names: Iterable[ServiceName],
 ) -> ServicePackage:
     """
     Parse and write service package docs.
 
     Arguments:
-        session -- boto3 session.
-        service_name -- Target service name.
-        output_path -- Package output path.
+        session -- boto3 session
+        service_name -- Target service name
+        output_path -- Package output path
+        service_names -- List of known service names
 
     Return:
         Parsed ServicePackage.
@@ -143,6 +151,9 @@ def process_service_docs(
     logger = get_logger()
     logger.debug(f"Parsing {service_name.boto3_name}")
     service_module = parse_service_package(session, service_name)
+    service_module.literals.append(
+        TypeLiteral("ServiceName", [i.boto3_name for i in service_names])
+    )
     logger.debug(f"Writing {service_name.boto3_name} to {NicePath(output_path)}")
 
     write_service_docs(service_module, output_path=output_path)
@@ -152,15 +163,15 @@ def process_service_docs(
 def process_boto3_stubs_docs(
     session: Session,
     output_path: Path,
-    service_names: List[ServiceName],
+    service_names: Iterable[ServiceName],
 ) -> Boto3StubsPackage:
     """
     Parse and write master package docs.
 
     Arguments:
-        session -- boto3 session.
-        output_path -- Package output path.
-        service_names -- List of known service names.
+        session -- boto3 session
+        output_path -- Package output path
+        service_names -- List of known service names
 
     Return:
         Parsed Boto3StubsPackage.
